## Installation & Setup
Install Letta:
```sh
pip install -U letta
```

To use Letta with OpenAI, set the environment variable `OPENAI_API_KEY` to your OpenAI key then run:
```
letta quickstart --backend openai
```
To use Letta with a free hosted endpoint, you run run:
```
letta quickstart --backend letta
```